aboutsummaryrefslogtreecommitdiff
path: root/test/nosplit.go
diff options
context:
space:
mode:
authorBryan C. Mills <bcmills@google.com>2019-10-16 20:41:53 +0000
committerBryan C. Mills <bcmills@google.com>2019-10-16 20:59:53 +0000
commitb76e6f88251712a21071d4ea11573bd8cdfa21de (patch)
tree8f61e6b95100c9ea5db743ed7934d0f253d3a58c /test/nosplit.go
parent2718789bc7937c58a7a65e53d9cc941b04682f99 (diff)
downloadgo-b76e6f88251712a21071d4ea11573bd8cdfa21de.tar.gz
go-b76e6f88251712a21071d4ea11573bd8cdfa21de.zip
Revert "cmd/compile, cmd/link, runtime: make defers low-cost through inline code and extra funcdata"
This reverts CL 190098. Reason for revert: broke several builders. Change-Id: I69161352f9ded02537d8815f259c4d391edd9220 Reviewed-on: https://go-review.googlesource.com/c/go/+/201519 Run-TryBot: Bryan C. Mills <bcmills@google.com> Reviewed-by: Austin Clements <austin@google.com> Reviewed-by: Dan Scales <danscales@google.com>
Diffstat (limited to 'test/nosplit.go')
-rw-r--r--test/nosplit.go6
1 files changed, 3 insertions, 3 deletions
diff --git a/test/nosplit.go b/test/nosplit.go
index 3b7e605999..266e6077b1 100644
--- a/test/nosplit.go
+++ b/test/nosplit.go
@@ -309,17 +309,17 @@ TestCases:
name := m[1]
size, _ := strconv.Atoi(m[2])
// The limit was originally 128 but is now 768 (896-128).
// Instead of rewriting the test cases above, adjust
// the first stack frame to use up the extra bytes.
if i == 0 {
- size += (896 - 128) - 128
+ size += (880 - 128) - 128
// Noopt builds have a larger stackguard.
// See ../src/cmd/dist/buildruntime.go:stackGuardMultiplier
// This increase is included in objabi.StackGuard
for _, s := range strings.Split(os.Getenv("GO_GCFLAGS"), " ") {
if s == "-N" {
- size += 896
+ size += 880
}
}
}
@@ -309,17 +309,17 @@ TestCases:
name := m[1]
size, _ := strconv.Atoi(m[2])
- // The limit was originally 128 but is now 768 (896-128).
+ // The limit was originally 128 but is now 752 (880-128).
// Instead of rewriting the test cases above, adjust
// the first stack frame to use up the extra bytes.